@@ -55,7 +55,6 @@ from . import settings_manager
 from . import sound_generator
 from . import speech_generator
 from . import structural_navigation
-from . import where_am_I
 from . import bookmarks
 from . import tutorialgenerator
 
@@ -115,7 +114,6 @@ class Script:
         self.speechGenerator = self.getSpeechGenerator()
         self.generatorCache = {}
         self.eventCache = {}
-        self.whereAmI = self.getWhereAmI()
         self.spellcheck = self.getSpellCheck()
         self.tutorialGenerator = self.getTutorialGenerator()
 
@@ -233,11 +231,6 @@ class Script:
         """
         return self.structuralNavigation.enabled
 
-    def getWhereAmI(self):
-        """Returns the "where am I" class for this script.
-        """
-        return where_am_I.WhereAmI(self)
-
     def getBookmarks(self):
         """Returns the "bookmarks" class for this script.
         """
@@ -405,6 +398,11 @@ class Script:
         except:
             msg = 'ERROR: Exception getting keyval_name for id: %d' % keyboardEvent.id
             debug.println(debug.LEVEL_INFO, msg, True)
+        else:
+            if keyboardEvent.event_string == '':
+                msg = 'INFO: Setting event_string to: %s' % keyboardEvent.keyval_name
+                debug.println(debug.LEVEL_INFO, msg, True)
+                keyboardEvent.event_string = keyboardEvent.keyval_name
 
     def consumesKeyboardEvent(self, keyboardEvent):
         """Called when a key is pressed on the keyboard.
@@ -551,3 +549,6 @@ class Script:
     def deactivate(self):
         """Called when this script is deactivated."""
         pass
+
+    def getTransferableAttributes(self):
+        return {}
